/**
 * Magic3 CKEditorプラグイン
 *
 * JavaScript 1.5
 *
 * LICENSE: This source file is licensed under the terms of the GNU General Public License.
 *
 * @package    Magic3 Framework
 * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 * @copyright  Copyright 2006-2017 Magic3 Project.
 * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
 * @version    1.0
 * @link       http://www.magic3.org
 */
CKEDITOR.plugins.setLang( 'googlemaps', 'en', {
	toolbar: 'Google Maps',
	title: 'Google Maps',
	mapTitle: 'Map',
	optionTitle: 'Option',
	searchTitle: 'Search',
	markerTitle: 'Marker',
	lineTitle: 'Line',
	styleTitle: 'Style',
	zoomControl: 'Zoom',
	panControl: 'Pan',
	scaleControl: 'Scale',
	mapTypeControl: 'Map Type',
	streetViewControl: 'Street View',
	rotateControl: 'Rotate',
	overviewMapControl: 'Overview Map',
	roadmapMapType: 'Map',
	satelliteMapType: 'Satellite',
	hybridMapType: 'Hybrid',
	terrainMapType: 'Terrain',
	width: 'Width',
	height: 'Height',
	widthType: '&nbsp;',
	heightType: '&nbsp;',
	alignCenter: 'align at center',
	zoomLevel: 'Zoom Level',
	control: 'Control',
	mapType: 'Map Type',
	msgDefaultMarkerText:	'Input text.',
	msgInputStyleJsonData: 'Input style data by JSON format.',
	msgInvalidStyle: 'Invalid JSON data.',
	msgApiKeyNotConfigured: 'Google Maps API key not configured.'
});
